@@ -550,7 +550,7 @@ def Upsample(dim):
 
 def BilinearUpsample(dim):
     return nn.Sequential(
-        nn.Upsample(scale_factor = 2),
+        nn.Upsample(scale_factor = 2, mode = 'bilinear'),
         nn.Conv2d(dim, dim, 3, padding = 1)
     )
 
@@ -568,8 +568,8 @@ def Downsample(dim, *, dim_out = None, antialias = False):
     dim_out = default(dim_out, dim)
 
     return nn.Sequential(
-        nn.Conv2d(dim, dim_out, 4, 2, 1),
-        Blur() if antialias else nn.Identity()
+        Blur() if antialias else nn.Identity(),
+        nn.Conv2d(dim, dim_out, 4, 2, 1)
     )
 
 class Scale(nn.Module):
@@ -969,10 +969,9 @@ class CrossEmbedLayer(nn.Module):
         self.blur = Blur() if antialias else nn.Identity()
 
     def forward(self, x):
+        x = self.blur(x)
         fmaps = tuple(map(lambda conv: conv(x), self.convs))
-        fmaps = torch.cat(fmaps, dim = 1)
-        fmaps = self.blur(fmaps)
-        return fmaps
+        return torch.cat(fmaps, dim = 1)
 
 class Unet(nn.Module):
     def __init__(
